Building Your First Display with Qt Designer
============================================

This section will guide you through the work necessary to create PyDM screens
using Qt Designer.

To make it more interesting, we will develop three pieces of the
:ref:`components <App Components>` described in our
:ref:`tutorial application <Application>`.

.. toctree::
   :maxdepth: 1
   :caption: Components

   designer_inline.rst
   designer_expert.rst
   designer_main.rst
